@@ -63,6 +63,32 @@ class Dataset():
         if (slug != ''):
             self._get_info_dataset_by_slug(slug)
 
+    def list_datasets(self):
+
+        s = requests.Session()
+        s.keep_alive = False
+        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
+        s.mount('https://', HTTPAdapter(max_retries=retries))
+
+        dataset_url = self._base_url_dataset + '/datasets?agentId=' + self._agentId
+        response = s.get(url=dataset_url, headers=self._headers)
+        response.raise_for_status()
+        r = response.json()
+        r_df = pd.DataFrame(r)
+
+        try:
+            if r_df.empty:
+                raise Exception('No datasets in the agent {}'.format(self._agentId))
+            else:
+                datasets_df = r_df.loc[:, ['id', 'domain', 'type', 'code', 'name', 'slug', 'description', 'createdBy', 'isActive',
+                                     'accessType', 'icon', 'version', 'syncCount', 'visible', 'public', 'createdAt']]
+        except Exception as e:
+            datasets_df = r_df
+            logging.info(e)
+
+        return datasets_df
+
+
     def _get_info_dataset_by_slug(self, slug: str):
 
         list_datasets = self.list_datasets()
