@@ -28,28 +28,12 @@ import _locale
 
 MANDATORY INPUT: my_app_id, my_app_secret, my_access_token, start_date, end_date,
 
-OPTIONAL:
-
-- account_name: dictionary with name and id. 
-                Optional, by default it gets 'Humable','Linkers','WinWay', 'Miss Tariffa Agency','Numbers', 'We are Fiber', 'Miss Tariffa'
 
 """
 
 
 
-def get_fb_ads(my_app_id, my_app_secret, my_access_token, start_date, end_date,
-               
-               #optional input below
-               
-               account_name = {'Numbers' : 'act_113103090066338',
-                'Linkers' : 'act_203938767415072',
-                'WinWay' : 'act_2591302164494270',
-                'Miss Tariffa Agency' : 'act_280378753012689',
-                'Humable' : 'act_284748836042514',
-                'Miss Tariffa' : 'act_503932150489858',
-                'We are Fiber' : 'act_638714426864395'
-               }
-              ):
+def get_fb_ads(my_app_id, my_app_secret, my_access_token, start_date, end_date, account_name):
     
     
     _locale._getdefaultlocale = (lambda *args: ['en_US', 'UTF-8'])
