@@ -124,7 +124,7 @@ def smart_substitution(sentence, language="en"):
         print("No substitution needed. Empty string or <mask> not in input sentence.")
 
 
-def smart_title(smartquery, metadata, lang="en-US"):
+def smart_title(smartquery, metadata, lang="en-US", update=False):
 
     if "en" not in lang.lower() and "it" not in lang.lower():
         lang = "en-US"
@@ -145,7 +145,8 @@ def smart_title(smartquery, metadata, lang="en-US"):
     data = {
         "smartquery": smartquery,
         "metadata": metadata,
-        "language": lang
+        "language": lang,
+        "update": update
     }
 
     r = s.post(url=url, headers=headers, json=data)
