@@ -2,7 +2,7 @@ import json
 import os
 import re
 from enum import Enum, auto
-from typing import List, Optional, Union
+from typing import List, Optional, Union, Dict
 from dataclasses import dataclass
 
 consistent_datatypes = {"numeric": ["bit", "smallmoney", "money", "int",
@@ -138,6 +138,7 @@ class Condition:
     field: Field
     operator: Optional[Union[SQLOperator, TimeOperator, PatternOperator, str]] = None
     value: Optional[List[Union[float, str]]] = None
+    conditionValue: Optional[List[Dict]] = None
     type: Optional[str] = None
     steps: Optional[str] = None
     interval: Optional[str] = None
