@@ -1,4 +1,4 @@
-from askdata.smart_synonym import suggest_synonyms
+from askdata.smartgraph import smart_synonyms
 
 if __name__ == "__main__":
 
@@ -6,7 +6,7 @@ if __name__ == "__main__":
     lang = "en"
     initial_synonyms_list = []
 
-    synonyms, business_name = suggest_synonyms(word=word, lang=lang, initial_synonyms_list=initial_synonyms_list)
+    synonyms, business_name = smart_synonyms(word=word, lang=lang, initial_synonyms_list=initial_synonyms_list)
 
     print("Synonyms: ")
     print(synonyms)
