@@ -13,7 +13,7 @@ if __name__ == '__main__':
     from3 = From('{{dataset.C}}')
     condition1 = Condition(field4, "FROM", direction="NEXT", negate=True, steps="{{number.A}}",
                            interval="{{timeDimension.B}}", value=["{{contextTimeStart.A}}", "{{contextTimeEnd.A}}"])
-    condition2 = Condition(field1, "LOE", ["{{number.B}}"])
+    condition2 = Condition(field1, "LOE", ["{{number.B}}"], conditionValue=[{"key1": "val1"}])
     condition3 = Condition(field2, "IN", ["{{entity.A}}"])
     condition4 = Condition(field4, "RANGE", value=["{{timePeriodStart.A}}", "{{timePeriodEnd.A}}"])
     condition5 = Condition(field5)
